@@ -10,15 +10,21 @@
  * The current page.
  *
  * @global string $self
- * @name $self
- * @var string
  */
 $self = preg_replace('|^.*/wp-admin/network/|i', '', $_SERVER['PHP_SELF']);
 $self = preg_replace('|^.*/wp-admin/|i', '', $self);
 $self = preg_replace('|^.*/plugins/|i', '', $self);
 $self = preg_replace('|^.*/mu-plugins/|i', '', $self);
 
-global $menu, $submenu, $parent_file; //For when admin-header is included from within a function.
+/**
+ * For when admin-header is included from within a function.
+ *
+ * @global array  $menu
+ * @global array  $submenu
+ * @global string $parent_file
+ * @global string $submenu_file
+ */
+global $menu, $submenu, $parent_file, $submenu_file;
 
 /**
  * Filter the parent file of an admin menu sub-menu item.
@@ -31,6 +37,16 @@ global $menu, $submenu, $parent_file; //For when admin-header is included from w
  */
 $parent_file = apply_filters( 'parent_file', $parent_file );
 
+/**
+ * Filter the file of an admin menu sub-menu item.
+ *
+ * @since 4.4.0
+ *
+ * @param string $submenu_file The submenu file.
+ * @param string $parent_file  The submenu item's parent file.
+ */
+$submenu_file = apply_filters( 'submenu_file', $submenu_file, $parent_file );
+
 get_admin_page_parent();
 
 /**
@@ -39,9 +55,15 @@ get_admin_page_parent();
  * @access private
  * @since 2.7.0
  *
+ * @global string $self
+ * @global string $parent_file
+ * @global string $submenu_file
+ * @global string $plugin_page
+ * @global string $typenow
+ *
  * @param array $menu
  * @param array $submenu
- * @param bool $submenu_as_parent
+ * @param bool  $submenu_as_parent
  */
 function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 	global $self, $parent_file, $submenu_file, $plugin_page, $typenow;
@@ -52,13 +74,15 @@ function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 		$admin_is_parent = false;
 		$class = array();
 		$aria_attributes = '';
+		$aria_hidden = '';
+		$is_separator = false;
 
 		if ( $first ) {
 			$class[] = 'wp-first-item';
 			$first = false;
 		}
 
-		$submenu_items = false;
+		$submenu_items = array();
 		if ( ! empty( $submenu[$item[2]] ) ) {
 			$class[] = 'wp-has-submenu';
 			$submenu_items = $submenu[$item[2]];
@@ -80,6 +104,10 @@ function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 		$img = $img_style = '';
 		$img_class = ' dashicons-before';
 
+		if ( false !== strpos( $class, 'wp-menu-separator' ) ) {
+			$is_separator = true;
+		}
+
 		/*
 		 * If the string 'none' (previously 'div') is passed instead of an URL, don't output
 		 * the default menu image so an icon can be added to div.wp-menu-image as background
@@ -104,9 +132,14 @@ function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 
 		$title = wptexturize( $item[0] );
 
-		echo "\n\t<li$class$id>";
+		// hide separators from screen readers
+		if ( $is_separator ) {
+			$aria_hidden = ' aria-hidden="true"';
+		}
 
-		if ( false !== strpos( $class, 'wp-menu-separator' ) ) {
+		echo "\n\t<li$class$id$aria_hidden>";
+
+		if ( $is_separator ) {
 			echo '<div class="separator"></div>';
 		} elseif ( $submenu_as_parent && ! empty( $submenu_items ) ) {
 			$submenu_items = array_values( $submenu_items );  // Re-index.
@@ -135,7 +168,7 @@ function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 
 		if ( ! empty( $submenu_items ) ) {
 			echo "\n\t<ul class='wp-submenu wp-submenu-wrap'>";
-			echo "<li class='wp-submenu-head'>{$item[0]}</li>";
+			echo "<li class='wp-submenu-head' aria-hidden='true'>{$item[0]}</li>";
 
 			$first = true;
 
@@ -163,7 +196,7 @@ function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 						$class[] = 'current';
 				// If plugin_page is set the parent must either match the current page or not physically exist.
 				// This allows plugin pages with the same hook to exist under different parents.
-				} else if (
+				} elseif (
 					( ! isset( $plugin_page ) && $self == $sub_item[2] ) ||
 					( isset( $plugin_page ) && $plugin_page == $sub_item[2] && ( $item[2] == $self_type || $item[2] == $self || file_exists($menu_file) === false ) )
 				) {
@@ -208,9 +241,12 @@ function _wp_menu_output( $menu, $submenu, $submenu_as_parent = true ) {
 
 ?>
 
+<div id="adminmenumain" role="navigation" aria-label="<?php esc_attr_e( 'Main menu' ); ?>">
+<a href="#wpbody-content" class="screen-reader-shortcut"><?php _e( 'Skip to main content' ); ?></a>
+<a href="#wp-toolbar" class="screen-reader-shortcut"><?php _e( 'Skip to toolbar' ); ?></a>
 <div id="adminmenuback"></div>
 <div id="adminmenuwrap">
-<ul id="adminmenu" role="navigation">
+<ul id="adminmenu">
 
 <?php
 
@@ -225,3 +261,4 @@ do_action( 'adminmenu' );
 ?>
 </ul>
 </div>
+</div>
